translate.tools.pypo2phppo

Package translate :: Package tools :: Module pypo2phppo |
[hide private]
[frames] | no frames]

# Module pypo2phppo

source code

Convert Python format .po files to PHP format .po files

Classes | [hide private]
| pypo2phppo

Functions | [hide private]
convertpy2php(inputfile, outputfile, template=None) Converts from Python .po to PHP .po | source code
main(argv=None) Converts from Python .po to PHP .po | source code

Imports: re, po, multistring

Function Details | [hide private]

### convertpy2php(inputfile, outputfile, template=None) | source code
Converts from Python .po to PHP .po Parameters: `inputfile` - file handle of the source `outputfile` - file handle to write to `template` - unused